@@ -1,17 +1,22 @@
 # -*- coding: utf-8 -*-
-from datetime import datetime
+from datetime import datetime, timedelta
 import logging
 
 from annoying.fields import JSONField
 from django.conf import settings
 from django.core.exceptions import ImproperlyConfigured
-from django.db import models, transaction
-from django.utils import timezone
+from django.db import models
 from django.utils.importlib import import_module
 from requests_oauthlib.oauth1_session import TokenRequestDenied
 from taggit.managers import TaggableManager
 
-from .exceptions import AccountLocked, LoginPasswordError
+from .exceptions import AccountLocked, LoginPasswordError, WrongAuthorizationResponseUrl
+
+try:
+    from django.db.transaction import atomic
+except ImportError:
+    from django.db.transaction import commit_on_success as atomic
+
 
 log = logging.getLogger('oauth_tokens')
 
@@ -40,7 +45,7 @@ class AccessTokenRefreshingError(Exception):
 class AccessTokenManager(models.Manager):
 
     '''
-    Defautl manager for AccessToken for retrieving token
+    Default manager for AccessToken for retrieving token
     '''
 
     def filter(self, *args, **kwargs):
@@ -50,12 +55,17 @@ class AccessTokenManager(models.Manager):
         tag = kwargs.pop('tag', None)
         if tag:
             kwargs['user_credentials__in'] = UserCredentials.objects.filter(
-                tags__name__in=[tag]).values_list('pk', flat=True)
+                tags__name__in=[tag]).values_list('pk')
 
         return super(AccessTokenManager, self).filter(*args, **kwargs)
 
     def filter_active_tokens_of_provider(self, provider, *args, **kwargs):
-        return self.filter(provider=provider, expires_at__gt=timezone.now(), *args, **kwargs).order_by('?')
+        # don't use timezone.now() for ability to cache querysets
+        next_hour = datetime(datetime.now().year,
+                             datetime.now().month,
+                             datetime.now().day,
+                             datetime.now().hour) + timedelta(hours=1)
+        return self.filter(provider=provider, expires_at__gt=next_hour, *args, **kwargs).order_by('?')
 
     def get_token(self, provider, tag=None):
         '''
@@ -126,7 +136,7 @@ class AccessTokenManager(models.Manager):
 
         return access_tokens
 
-    @transaction.commit_on_success
+    @atomic
     def fetch(self, provider):
         '''
         Get new token and save it to database for all users in UserCredentials table.
@@ -146,7 +156,7 @@ class AccessTokenManager(models.Manager):
 
             try:
                 token = self.get_token_of_class(token_class, user).get()
-            except (TokenRequestDenied, AccountLocked, LoginPasswordError), e:
+            except (TokenRequestDenied, AccountLocked, LoginPasswordError, WrongAuthorizationResponseUrl), e:
                 log.error(u"Error '%s' while getting new token for provider %s and user %s" % (e, provider, user))
                 user.inactivate(e)
                 continue
